# 0.11.5 (2022-01-11)

### Improvements

-   Updated Yandex Maps schema ([d16ffe4](https://github.com/nalgeon/iuliia-py/commit/d16ffe4b5b4f2bde3f8fb2c1799a4b1bf86be354))

# 0.11.4 (2021-05-05)

### Bug Fixes

-   Bumped minimal Python version to 3.7, fixes [#3](https://github.com/nalgeon/iuliia-py/issues/3)

# 0.11.3 (2020-05-05)

### Bug Fixes

-   Enforce schema encoding, fixes [#1](https://github.com/nalgeon/iuliia-py/issues/1) ([b810c26](https://github.com/nalgeon/iuliia-py/commit/b810c261936b488c52947f696b8cc486b7c2a4d6))

# 0.11.2 (2020-05-04)

### Bug Fixes

-   Split sentence by word boundary ([76fabee](https://github.com/nalgeon/iuliia-py/commit/76fabee8f13f3b3c5374603633c8b19fdeb002e6))

# 0.11.1 (2020-04-30)

-   Schema description and Mypy type checking

# 0.11.0 (2020-04-29)

### Features

-   Moscow Metro map schema ([2d86f19](https://github.com/nalgeon/iuliia-py/commit/2d86f193b27f0b94ea7090c726a3f9d86c56c174))

# 0.10.0 (2020-04-27)

### Features

-   Declarative schema definition ([bc902e5](https://github.com/nalgeon/iuliia-py/commit/bc902e503cb5b5b26093e890aff68fedbf3fb230))

# 0.9.0 (2020-04-24)

-   Refactored transliteration schemas into separate package. Nothing changed in external API.

# 0.8.0 (2020-04-23)

### Features

-   UN, scientific and library schemas ([d3f8462](https://github.com/nalgeon/iuliia-py/commit/d3f8462359e8c731d4b41cc92ff01bbf1ca6cfad))

# 0.7.0 (2020-04-22)

### Bug Fixes

-   mapping capitalization for different cases ([105d955](https://github.com/nalgeon/iuliia-py/commit/105d9551830c1149b14103c13ddc6ddb716289a3))

### Features

-   ICAO, ISO and telegram schemas ([26e3900](https://github.com/nalgeon/iuliia-py/commit/26e390068e86c86913a7a8a74d288613585f88fb))

# 0.6.0 (2020-04-21)

### Features

-   GOST and MVD schemas ([36688f7](https://github.com/nalgeon/iuliia-py/commit/36688f7f01858ee6f00bb7ef92a2e39da22b308f))

# 0.5.0 (2020-04-20)

### Features

-   command-line interface ([52fd29c](https://github.com/nalgeon/iuliia-py/commit/52fd29cc79219d2600aa709ab6d139318b2138c0))

# 0.4.0 (2020-04-20)

### Features

-   Wikipedia and Yandex.Maps schemas ([df7b5a3](https://github.com/nalgeon/iuliia-py/commit/df7b5a38030099d422c360d8e70f55e5cc98ebc1))

# 0.3.0 (2020-04-20)

### Features

-   Yandex.Money schema ([2430b32](https://github.com/nalgeon/iuliia-py/commit/2430b32b73f85bf1a7dc783180ad2479062fda7a))

# 0.2.1 (2020-04-20)

### Features

-   basic transliteration features ([72e5220](https://github.com/nalgeon/iuliia-py/commit/72e522093dc02172c84f9678be6904756a8d6ee3))
